@@ -129,7 +129,6 @@ class PipelineDefinition(IContainSolids, object):
         dependencies=None,
         mode_defs=None,
         preset_defs=None,
-        selector=None,
     ):
         self._name = check.opt_str_param(name, 'name', '<<unnamed>>')
         self._description = check.opt_str_param(description, 'description')
@@ -158,11 +157,11 @@ class PipelineDefinition(IContainSolids, object):
 
         self._dependencies = validate_dependency_dict(dependencies)
 
-        dependency_structure, pipeline_solid_dict = create_execution_structure(
+        dependency_structure, solid_dict = create_execution_structure(
             self._current_level_solid_defs, self._dependencies, container_definition=None
         )
 
-        self._solid_dict = pipeline_solid_dict
+        self._solid_dict = solid_dict
         self._dependency_structure = dependency_structure
 
         self._runtime_type_dict = construct_runtime_type_dictionary(self._current_level_solid_defs)
@@ -197,9 +196,20 @@ class PipelineDefinition(IContainSolids, object):
             for solid_def in current_level_solid_def.iterate_solid_defs():
                 self._all_solid_defs[solid_def.name] = solid_def
 
-        self._selector = check.opt_inst_param(
-            selector, 'selector', ExecutionSelector, ExecutionSelector(self._name)
-        )
+        self._selector = ExecutionSelector(self.name, list(solid_dict.keys()))
+
+        self._cached_enviroment_schemas = {}
+
+    def get_environment_schema(self, mode=None):
+        check.str_param(mode, 'mode')
+
+        mode_def = self.get_mode_definition(mode)
+
+        if mode_def.name in self._cached_enviroment_schemas:
+            return self._cached_enviroment_schemas[mode_def.name]
+
+        self._cached_enviroment_schemas[mode_def.name] = _create_environment_schema(self, mode_def)
+        return self._cached_enviroment_schemas[mode_def.name]
 
     @property
     def name(self):
@@ -452,7 +462,6 @@ def _build_sub_pipeline(pipeline_def, solid_names):
         solid_defs=list({solid.definition for solid in solids}),
         mode_defs=pipeline_def.mode_definitions,
         dependencies=deps,
-        selector=ExecutionSelector(pipeline_def.name, solid_names),
     )
     handle, _ = ExecutionTargetHandle.get_handle(pipeline_def)
     if handle:
@@ -548,3 +557,34 @@ class PipelineRunsFilter(
             pipeline=check.opt_str_param(pipeline, 'pipeline'),
             status=status,
         )
+
+
+def _create_environment_schema(pipeline_def, mode_definition):
+    from .environment_configs import (
+        EnvironmentClassCreationData,
+        construct_config_type_dictionary,
+        define_environment_cls,
+    )
+    from .environment_schema import EnvironmentSchema
+
+    environment_cls = define_environment_cls(
+        EnvironmentClassCreationData(
+            pipeline_name=pipeline_def.name,
+            solids=pipeline_def.solids,
+            dependency_structure=pipeline_def.dependency_structure,
+            mode_definition=mode_definition,
+            logger_defs=mode_definition.loggers,
+        )
+    )
+
+    environment_type = environment_cls.inst()
+
+    config_type_dict_by_name, config_type_dict_by_key = construct_config_type_dictionary(
+        pipeline_def.all_solid_defs, environment_type
+    )
+
+    return EnvironmentSchema(
+        environment_type=environment_type,
+        config_type_dict_by_name=config_type_dict_by_name,
+        config_type_dict_by_key=config_type_dict_by_key,
+    )
