@@ -355,6 +355,26 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
     def solid_named(self, name):
         return self._solid_dict[name]
 
+    def has_solid_named(self, name):
+        check.str_param(name, 'name')
+        return name in self._solid_dict
+
+    def get_solid(self, handle):
+        check.inst_param(handle, 'handle', SolidHandle)
+        current = handle
+        lineage = []
+        while current:
+            lineage.append(current.name)
+            current = current.parent
+
+        name = lineage.pop()
+        solid = self.solid_named(name)
+        while lineage:
+            name = lineage.pop()
+            solid = solid.definition.solid_named(name)
+
+        return solid
+
     @property
     def dependency_structure(self):
         return self._dependency_structure
@@ -371,6 +391,15 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
     def has_config_mapping(self):
         return self._config_mapping is not None
 
+    @property
+    def has_descendant_config_mapping(self):
+        return any(
+            (
+                isinstance(solid, CompositeSolidDefinition) and solid.has_config_mapping
+                for solid in self.iterate_solid_defs()
+            )
+        )
+
     @property
     def has_config_entry(self):
         has_solid_config = any([solid.definition.has_config_entry for solid in self.solids])
