@@ -255,7 +255,7 @@ def create_tuple_error(context):
             'Value {path_msg} must be a tuple with {n_values} values. Expected: '
             '{type_name}'.format(
                 path_msg=get_friendly_path_msg(context.stack),
-                n_values=len(context.config_type.inner_type),
+                n_values=len(context.config_type.tuple_types),
                 type_name=print_config_type_to_string(context.config_type, with_lines=False),
             )
         ),
@@ -405,26 +405,6 @@ def create_bad_mapping_error(context, fn_name, solid_def_name, handle_name, mapp
     )
 
 
-def create_bad_mapping_solids_key_error(context, solid_def_name, handle_name):
-    check.inst_param(context, 'context', TraversalContext)
-
-    return EvaluationError(
-        stack=context.stack,
-        reason=DagsterEvaluationErrorReason.RUNTIME_TYPE_MISMATCH,
-        message=(
-            'Environment contains "solids" key but config mapping defined by solid {handle_name} '
-            'from definition {solid_def_name} {path_msg} is provided; "solids" should not be '
-            'provided when a config mapping override is used {config_value}'.format(
-                handle_name=handle_name,
-                solid_def_name=solid_def_name,
-                path_msg=get_friendly_path_msg(context.stack),
-                config_value=context.config_value,
-            )
-        ),
-        error_data=RuntimeMismatchErrorData(context.config_type, repr(context.config_value)),
-    )
-
-
 def create_bad_user_config_fn_error(context, fn_name, handle_name, solid_def_name, exc_info):
     return EvaluationError(
         stack=context.stack,
